# Modeling Pace Layers
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?version=CLOUD#overview)
  * [Pace Layering Using Tags](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?version=CLOUD#pace-layering-using-tags)
  * [Pace Layering Using Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?version=CLOUD#pace-layering-using-fact-sheet-fields)
  * [Pace Layering Using Fields on Relations](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?version=CLOUD#pace-layering-using-fields-on-relations)
  * [Using Diagrams to Analyze Pace Layering](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?version=CLOUD#using-diagrams-to-analyze-pace-layering)


Learn how to model the pace layering classification in SAP LeanIX.
